# revnext

Download Revolution Next (*.revolutionnext.com.au) reports (Parts Price List, Parts by Bin Location) via REST API using cookies/session.

Install: `pip install revnext`  
Or from repo root: `pip install -e ./packages/revnext`

See the [main repo README](../README.md) for configuration and usage.
